@@ -51,7 +51,8 @@
 	    egg-end-conversion            mana-commit
 	    ;;
 	    egg-get-source-language       mana-get-source-language
-	    egg-get-converted-language    mana-get-converted-language))
+	    egg-get-converted-language    mana-get-converted-language
+	    egg-word-registration         mana-word-registration))
 
 (defconst mana-backend-alist '((Japanese ((mana-conversion-backend)))))
 
@@ -128,6 +129,9 @@
 (defun mana-list-candidates (yomi state pos mrph-len len)
   (mana-eval `(mana-list-candidates ,yomi ,state ,pos ,mrph-len ,len)))
 
+(defun mana-add-new-word (kaki yomi)
+  (mana-cmd `(mana-add-new-word ,kaki ,yomi)))
+
 ;;
 ;; <mana-bunsetsu> ::=
 ;;  [ <string> <pos> <len> <state> <converted> <candidates> <candidate-pos> ]
@@ -250,6 +254,15 @@ Return the list of bunsetsu."
 	(delete-process mana-proc)
 	(setq mana-proc nil))))
 
+;;Register new word
+(defun mana-word-registration (backend str yomi)
+  (let ((str (copy-sequence str))
+	(yomi (copy-sequence yomi)))
+    (set-text-properties 0 (length str) nil str)
+    (set-text-properties 0 (length yomi) nil yomi)
+    (mana-add-new-word str yomi)
+    '("̤" "Ŀͼ")))
+
 ;;; setup
 
 (run-hooks 'mana-load-hook)
