@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: chasen.ml 76 2005-05-04 22:08:15Z yori $ *)
+(* $Id: chasen.ml 103 2005-07-08 17:17:50Z yori $ *)
 
 type darts
 type mrph_prim
@@ -87,6 +87,8 @@ external mrph_data_base : mrph_data_prim -> string = "mrph_data_base"
 external mrph_data_info : mrph_data_prim -> string = "mrph_data_info"
 external mrph_data_compound : mrph_data_prim -> int = "mrph_data_compound"
 
+external new_mrph_data : posid:int -> inf_type:int -> inf_form:int -> weight:int -> con_tbl:int -> dat_index:int -> keyword:string -> is_undef:int -> darts:darts -> headword:string -> stem_len:int -> reading:string -> pron:string -> base:string -> info:string -> compound:int -> mrph_data_prim = "new_mrph_data_byte" "new_mrph_data_opt"
+
 external delete_mrph_data : mrph_data_prim -> unit = "delete_mrph_data"
 external mrph_data_of_mrph : mrph_prim -> mrph_data_prim = "mrph_data_of_mrph"
 
@@ -279,3 +281,53 @@ let surface_form d =
 	headword ^ gobi
     else
       headword
+
+let serialize_mrph mrph =
+  let mrph_data = mrph_data_of_mrph mrph in
+  Printf.sprintf 
+    "1,%d,%d,%d,%d,%d,%S,%S,%S,%S,%d,%S,%S,%d"
+    (posid mrph_data)
+    (inf_type mrph_data)
+    (inf_form mrph_data)
+    (weight mrph_data)
+    (con_tbl mrph_data)
+    (keyword mrph_data)
+    (headword mrph_data)
+    (reading mrph_data)
+    (pron mrph_data)
+    (stem_len mrph_data)
+    (base mrph_data)
+    (info mrph_data)
+    (compound mrph_data)
+
+let deserialize_mrph string =
+  Scanf.sscanf string
+    "1,%d,%d,%d,%d,%d,%S,%S,%S,%S,%d,%S,%S,%d"
+    (fun posid inf_type	inf_form weight con_tbl keyword headword	
+	reading	pron stem_len base info	compound ->
+	  `Mrph_data (new_mrph_data
+			~posid
+			~inf_type
+			~inf_form
+			~weight
+			~con_tbl
+			~keyword
+			~headword
+			~reading
+			~pron
+			~stem_len
+			~base
+			~info
+			~compound
+			~is_undef:0
+			(* FIXME *)
+			~dat_index:0
+			~darts:(Obj.magic 0)))
+		
+let new_word ~kaki ~yomi  =
+  let mrph_list = ref [] in
+  for no = 0 to undef_info_num - 1 do
+    mrph_list :=
+      create_undefword yomi kaki mrph_default_weight no :: !mrph_list
+  done;
+  !mrph_list
