@@ -12,6 +12,14 @@
 (*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
 (*  General Public License for more details.                              *)
 (**************************************************************************)
+
+let dic_lookup s p len = 
+  PersonalDict.lookup s p len @
+  Chasen.darts_lookup s p len
+
+let dic_lookup_prefix s p len =
+  PersonalDict.lookup_prefix s p len @ 
+  Chasen.darts_lookup_prefix s p len
  
 let connect_mrph ~state ~mrph =
   let new_state, con_cost = 
@@ -119,7 +127,7 @@ let add_vertex ~pos ~to_pos ~state mrph node_set =
       Hashtbl.add node_set.(to_pos) new_state to_node
 
 let list_next_mrph string ~pos ~len =
-  Chasen.darts_lookup_prefix string pos len
+  dic_lookup_prefix string pos len
 
 let parse string ~state ~pos ~len =
   if len <= 0 then Array.init 0 Hashtbl.create else
@@ -173,7 +181,7 @@ let best_path node_set pos =
   gather last_node []
   
 let list_candidates string ~state ~pos ~mrph_len ~len =
-  let mrph_list = Chasen.darts_lookup string pos mrph_len in
+  let mrph_list = dic_lookup string pos mrph_len in
   let mrph_list = 
     Chasen.undefwords (EucString.sub string pos mrph_len) @ mrph_list in
   let f mrph =
