@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: parse.mli 82 2005-05-15 11:39:17Z yori $ *)
+(* $Id: parse.mli 92 2005-05-28 19:24:23Z yori $ *)
 
 (** ʸĹʸΰ֤EUCʸοɽ롣*)
 
@@ -30,7 +30,7 @@ l, state, cost)]ΥꥹȤȤɽ졢[p]ʸΰ֡[l]б
 ʬʸĹ[state][mrph]Ϣܤľξ֡[cost]
 [mrph]ޤ᤿[mrph]ޤǤȡ*)
 val best_path : parse_obj -> int -> 
-  (Chasen.mrph * int * int * int * int) list * int * int
+  (Chasen.mrph * int * int * int * int) list
 
 (** [list_candidates string state pos mrph_len len][state]ȯ
 [string][pos]Ĺ[mrph_len]ʬʸбǤ󤹤롣
